AppDistributionDistributeOptions class
Options for firebase appdistribution:distribute with test case IDs (Method B).
- Annotations
-
- @immutable
Constructors
Properties
- apkPath → String
-
final
- appId → String
-
Firebase Android App ID, e.g.
1:123:android:abc.final - groups → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- releaseNotes → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
testCaseIds
→ List<
String> -
final
-
testDevices
→ List<
String> -
Same format as YAML
devicesentries.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited